summaryrefslogtreecommitdiffstats
path: root/kcontrol/input/xcursor
diff options
context:
space:
mode:
Diffstat (limited to 'kcontrol/input/xcursor')
-rw-r--r--kcontrol/input/xcursor/themepage.cpp12
-rw-r--r--kcontrol/input/xcursor/themepage.h2
2 files changed, 7 insertions, 7 deletions
diff --git a/kcontrol/input/xcursor/themepage.h b/kcontrol/input/xcursor/themepage.h
index 548ed0063..bc284aa48 100644
--- a/kcontrol/input/xcursor/themepage.h
+++ b/kcontrol/input/xcursor/themepage.h
@@ -34,7 +34,7 @@ struct ThemeInfo;
class ThemePage : public TQWidget
{
- Q_OBJECT
+ TQ_OBJECT
public:
ThemePage( TQWidget* parent = 0, const char* name = 0 );
diff --git a/kcontrol/input/xcursor/themepage.cpp b/kcontrol/input/xcursor/themepage.cpp
index c4c73396a..e575b6cd2 100644
--- a/kcontrol/input/xcursor/themepage.cpp
+++ b/kcontrol/input/xcursor/themepage.cpp
@@ -100,8 +100,8 @@ ThemePage::ThemePage( TQWidget* parent, const char* name )
listview->addColumn( i18n("Name") );
listview->addColumn( i18n("Description") );
- connect( listview, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
- TQT_SLOT(selectionChanged(TQListViewItem*)) );
+ connect( listview, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+ TQ_SLOT(selectionChanged(TQListViewItem*)) );
themeDirs = getThemeBaseDirs();
insertThemes();
@@ -111,8 +111,8 @@ ThemePage::ThemePage( TQWidget* parent, const char* name )
installButton = new TQPushButton( i18n("Install New Theme..."), hbox );
removeButton = new TQPushButton( i18n("Remove Theme"), hbox );
- connect( installButton, TQT_SIGNAL( clicked() ), TQT_SLOT( installClicked() ) );
- connect( removeButton, TQT_SIGNAL( clicked() ), TQT_SLOT( removeClicked() ) );
+ connect( installButton, TQ_SIGNAL( clicked() ), TQ_SLOT( installClicked() ) );
+ connect( removeButton, TQ_SIGNAL( clicked() ), TQ_SLOT( removeClicked() ) );
// Disable the install button if ~/.icons isn't writable
TQString path = TQDir::homeDirPath() + "/.icons";
@@ -580,7 +580,7 @@ TQPixmap ThemePage::createIcon( const TQString &theme, const TQString &sample )
// Calculate the image size
int size = kMax( iconSize, kMax( r.width(), r.height() ) );
// Create the intermediate QImage
TQImage image( size, size, 32 );
image.setAlphaBuffer( true );
@@ -621,7 +621,7 @@ TQPixmap ThemePage::createIcon( const TQString &theme, const TQString &sample )
// Scale down the image if we need to
if ( image.width() > iconSize || image.height() > iconSize )
- image = image.smoothScale( iconSize, iconSize, TQ_ScaleMin );
+ image = image.smoothScale( iconSize, iconSize, TQImage::ScaleMin );
pix.convertFromImage( image );
XcursorImageDestroy( xcur );
@@ -580,7 +580,7 @@ TQPixmap ThemePage::createIcon( const TQString &theme, const TQString &sample )
// Calculate the image size
int size = kMax( iconSize, kMax( r.width(), r.height() ) );
- // Create the intermediate QImage
+ // Create the intermediate TQImage
TQImage image( size, size, 32 );
image.setAlphaBuffer( true );